@@ -62,9 +62,11 @@ var httpTestcases = []TestCaseInfo{
 	{Path: "protocols/http/dsl-functions.yaml", TestCase: &httpDSLFunctions{}},
 	{Path: "protocols/http/race-simple.yaml", TestCase: &httpRaceSimple{}},
 	{Path: "protocols/http/race-multiple.yaml", TestCase: &httpRaceMultiple{}},
+	{Path: "protocols/http/race-with-variables.yaml", TestCase: &httpRaceWithVariables{}},
 	{Path: "protocols/http/stop-at-first-match.yaml", TestCase: &httpStopAtFirstMatch{}},
 	{Path: "protocols/http/stop-at-first-match-with-extractors.yaml", TestCase: &httpStopAtFirstMatchWithExtractors{}},
 	{Path: "protocols/http/variables.yaml", TestCase: &httpVariables{}},
+	{Path: "protocols/http/variables-threads-previous.yaml", TestCase: &httpVariablesThreadsPrevious{}},
 	{Path: "protocols/http/variable-dsl-function.yaml", TestCase: &httpVariableDSLFunction{}},
 	{Path: "protocols/http/get-override-sni.yaml", TestCase: &httpSniAnnotation{}},
 	{Path: "protocols/http/get-sni.yaml", TestCase: &customCLISNI{}},
@@ -77,6 +79,7 @@ var httpTestcases = []TestCaseInfo{
 	{Path: "protocols/http/cl-body-without-header.yaml", TestCase: &httpCLBodyWithoutHeader{}},
 	{Path: "protocols/http/cl-body-with-header.yaml", TestCase: &httpCLBodyWithHeader{}},
 	{Path: "protocols/http/cli-with-constants.yaml", TestCase: &ConstantWithCliVar{}},
+	{Path: "protocols/http/constants-with-threads.yaml", TestCase: &constantsWithThreads{}},
 	{Path: "protocols/http/matcher-status.yaml", TestCase: &matcherStatusTest{}},
 	{Path: "protocols/http/disable-path-automerge.yaml", TestCase: &httpDisablePathAutomerge{}},
 	{Path: "protocols/http/http-preprocessor.yaml", TestCase: &httpPreprocessor{}},
@@ -1153,6 +1156,26 @@ func (h *httpRaceMultiple) Execute(filePath string) error {
 	return expectResultsCount(results, 5)
 }
 
+type httpRaceWithVariables struct{}
+
+// Execute tests that variables and constants are properly resolved in race mode.
+func (h *httpRaceWithVariables) Execute(filePath string) error {
+	router := httprouter.New()
+	router.GET("/race", func(w http.ResponseWriter, r *http.Request, _ httprouter.Params) {
+		// Echo back the API key header so we can match on it
+		_, _ = fmt.Fprint(w, r.Header.Get("X-API-Key"))
+	})
+	ts := httptest.NewServer(router)
+	defer ts.Close()
+
+	results, err := testutils.RunNucleiTemplateAndGetResults(filePath, ts.URL, debug)
+	if err != nil {
+		return err
+	}
+
+	return expectResultsCount(results, 3)
+}
+
 type httpStopAtFirstMatch struct{}
 
 // Execute executes a test case and returns an error if occurred
@@ -1220,6 +1243,30 @@ func (h *httpVariables) Execute(filePath string) error {
 	return expectResultsCount(results, 0)
 }
 
+type httpVariablesThreadsPrevious struct{}
+
+// Execute tests that variables can reference data extracted from previous requests
+// when using threads mode (parallel execution).
+func (h *httpVariablesThreadsPrevious) Execute(filePath string) error {
+	router := httprouter.New()
+	router.GET("/login", func(w http.ResponseWriter, r *http.Request, _ httprouter.Params) {
+		_, _ = fmt.Fprint(w, "token=secret123")
+	})
+	router.GET("/api", func(w http.ResponseWriter, r *http.Request, _ httprouter.Params) {
+		// Echo back the Authorization header so we can match on it
+		_, _ = fmt.Fprint(w, r.Header.Get("Authorization"))
+	})
+	ts := httptest.NewServer(router)
+	defer ts.Close()
+
+	results, err := testutils.RunNucleiTemplateAndGetResults(filePath, ts.URL, debug)
+	if err != nil {
+		return err
+	}
+
+	return expectResultsCount(results, 1)
+}
+
 type httpVariableDSLFunction struct{}
 
 // Execute executes a test case and returns an error if occurred
@@ -1466,6 +1513,26 @@ func (h *ConstantWithCliVar) Execute(filePath string) error {
 	return expectResultsCount(got, 1)
 }
 
+type constantsWithThreads struct{}
+
+// Execute tests that constants are properly resolved when using threads mode.
+func (h *constantsWithThreads) Execute(filePath string) error {
+	router := httprouter.New()
+	router.GET("/api/:version", func(w http.ResponseWriter, r *http.Request, p httprouter.Params) {
+		// Echo back the API key header and version so we can match on them
+		_, _ = fmt.Fprintf(w, "%s %s", r.Header.Get("X-API-Key"), p.ByName("version"))
+	})
+	ts := httptest.NewServer(router)
+	defer ts.Close()
+
+	results, err := testutils.RunNucleiTemplateAndGetResults(filePath, ts.URL, debug)
+	if err != nil {
+		return err
+	}
+
+	return expectResultsCount(results, 1)
+}
+
 type matcherStatusTest struct{}
 
 // Execute executes a test case and returns an error if occurred
