@@ -9,7 +9,7 @@ import (
 )
 
 func memoizedisMySQL(executionId string, host string, port int) (bool, error) {
-	hash := "isMySQL" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
+	hash := "isMySQL" + ":" + fmt.Sprint(executionId) + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
 		return isMySQL(executionId, host, port)
@@ -25,7 +25,7 @@ func memoizedisMySQL(executionId string, host string, port int) (bool, error) {
 }
 
 func memoizedfingerprintMySQL(executionId string, host string, port int) (MySQLInfo, error) {
-	hash := "fingerprintMySQL" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
+	hash := "fingerprintMySQL" + ":" + fmt.Sprint(executionId) + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
 		return fingerprintMySQL(executionId, host, port)
