@@ -9,7 +9,7 @@ import (
 )
 
 func memoizedisRsync(executionId string, host string, port int) (IsRsyncResponse, error) {
-	hash := "isRsync" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
+	hash := "isRsync" + ":" + fmt.Sprint(executionId) + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
 		return isRsync(executionId, host, port)
