@@ -9,7 +9,7 @@ import (
 )
 
 func memoizedisVNC(executionId string, host string, port int) (IsVNCResponse, error) {
-	hash := "isVNC" + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
+	hash := "isVNC" + ":" + fmt.Sprint(executionId) + ":" + fmt.Sprint(host) + ":" + fmt.Sprint(port)
 
 	v, err, _ := protocolstate.Memoizer.Do(hash, func() (interface{}, error) {
 		return isVNC(executionId, host, port)
